.. Algorithm Toolkit documentation master file

=====================================================
Welcome to the Algorithm Toolkit (ATK) documentation!
=====================================================
This project provides an easy way for researchers and developers to develop and share algorithms related to geospatial data and imagery.

The source code for this project lives on `GitHub <https://github.com/BeamIO-Inc/algorithm_toolkit>`_.

Contents
--------

.. toctree::
   :maxdepth: 2

   about
   quick_start
   pycharm
   atk-project
   dev-environment
   working-with-algorithms
   creating-your-first-algorithm
   working-with-chains
   chain-ledger
   tutorial
   cli
   api
   docker
   algorithm-registry
   contributing


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
